Reset your password to continue using {{service_name}}

Hi {{user_name}}, Your token will expire in {{days_left}} days. Go to IAM > ‘App’ page and regenerate the Client Secret of ‘{{app_name}}’. App Name: {{app_name}} App ID: {{app_id}} Workspace Name: {{workspace_name}} Expired At: {{expired_at}}
Go to Console
Sincerely yours, {{service_name}}
Homepage | Blog | Help Center Copyright 2024 © MEGAZONE CLOUD Corp. All Right Reserved.